@@ -15,6 +15,7 @@ from __future__ import annotations
 from typing import *
 
 from ...core.func import GetAttr, Join
+from .TakeOverTypeModelRef import TakeOverTypeModelRef
 
 
 class NamespaceRef:
@@ -26,6 +27,15 @@ class NamespaceRef:
     ):
         self.namespace_name = namespace_name
 
+    def take_over_type_model(
+        self,
+        type: int,
+    ) -> TakeOverTypeModelRef:
+        return TakeOverTypeModelRef(
+            self.namespace_name,
+            type,
+        )
+
     def grn(
         self,
     ) -> str:
