@@ -21,6 +21,7 @@ from ..stamp_sheet.SetMoldCapacityByUserId import SetMoldCapacityByUserId
 from ..stamp_sheet.AcquireActionsToFormProperties import AcquireActionsToFormProperties
 from ...core.model import AcquireAction
 from ...core.model import Config
+from ..stamp_sheet.SetFormByUserId import SetFormByUserId
 from ..stamp_sheet.SubMoldCapacityByUserId import SubMoldCapacityByUserId
 
 
@@ -84,6 +85,20 @@ class MoldModelRef:
             user_id,
         )
 
+    def set_form(
+        self,
+        index: int,
+        slots: List[Slot],
+        user_id: Optional[str] = "#{userId}",
+    ) -> SetFormByUserId:
+        return SetFormByUserId(
+            self.namespace_name,
+            self.mold_model_name,
+            index,
+            slots,
+            user_id,
+        )
+
     def sub_mold_capacity(
         self,
         capacity: int,
