@@ -15,6 +15,7 @@ from __future__ import annotations
 from typing import *
 
 from ...core.func import GetAttr, Join
+from ..stamp_sheet.UpdateProfileByUserId import UpdateProfileByUserId
 
 
 class NamespaceRef:
@@ -26,6 +27,21 @@ class NamespaceRef:
     ):
         self.namespace_name = namespace_name
 
+    def update_profile(
+        self,
+        public_profile: Optional[str] = None,
+        follower_profile: Optional[str] = None,
+        friend_profile: Optional[str] = None,
+        user_id: Optional[str] = "#{userId}",
+    ) -> UpdateProfileByUserId:
+        return UpdateProfileByUserId(
+            self.namespace_name,
+            public_profile,
+            follower_profile,
+            friend_profile,
+            user_id,
+        )
+
     def grn(
         self,
     ) -> str:
