@@ -11,6 +11,8 @@
 # on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 # express or implied. See the License for the specific language governing
 # permissions and limitations under the License.
+#
+# deny overwrite
 from __future__ import annotations
 from typing import *
 
@@ -19,7 +21,7 @@ from ...core.func import GetAttr
 from .RoleModel import RoleModel
 
 from ..ref.GuildRef import GuildRef
-from .enum.GuildJoinPolicy import GuildJoinPolicy
+from .enums.GuildJoinPolicy import GuildJoinPolicy
 
 from .options.GuildOptions import GuildOptions
 
@@ -80,7 +82,7 @@ class Guild(CdkResource):
     def alternate_keys(
         self,
     ):
-        return "guild_model_name + ":" + name"
+        return self.guild_model_name + ":" + self.display_name
 
     def resource_type(
         self,
