@@ -15,6 +15,14 @@ from .Namespace import Namespace
 from .options.NamespaceOptions import NamespaceOptions
 from .CategoryModel import CategoryModel
 from .options.CategoryModelOptions import CategoryModelOptions
+from .VerifyActionResult import VerifyActionResult
+from .options.VerifyActionResultOptions import VerifyActionResultOptions
+from .ConsumeActionResult import ConsumeActionResult
+from .options.ConsumeActionResultOptions import ConsumeActionResultOptions
+from .AcquireActionResult import AcquireActionResult
+from .options.AcquireActionResultOptions import AcquireActionResultOptions
+from .TransactionResult import TransactionResult
+from .options.TransactionResultOptions import TransactionResultOptions
 from .AcquireActionList import AcquireActionList
 from .options.AcquireActionListOptions import AcquireActionListOptions
 from .CurrentMasterData import CurrentMasterData
\ No newline at end of file
