@@ -13,43 +13,45 @@
 # permissions and limitations under the License.
 from .CounterScopeModel import CounterScopeModel
 from .options.CounterScopeModelOptions import CounterScopeModelOptions
-from .enum.CounterScopeModelScopeType import CounterScopeModelScopeType
-from .enum.CounterScopeModelResetType import CounterScopeModelResetType
-from .enum.CounterScopeModelResetDayOfWeek import CounterScopeModelResetDayOfWeek
+from .enums.CounterScopeModelScopeType import CounterScopeModelScopeType
+from .enums.CounterScopeModelResetType import CounterScopeModelResetType
+from .enums.CounterScopeModelResetDayOfWeek import CounterScopeModelResetDayOfWeek
 from .options.CounterScopeModelScopeTypeIsResetTimingOptions import CounterScopeModelScopeTypeIsResetTimingOptions
 from .options.CounterScopeModelScopeTypeIsVerifyActionOptions import CounterScopeModelScopeTypeIsVerifyActionOptions
 from .options.CounterScopeModelResetTypeIsNotResetOptions import CounterScopeModelResetTypeIsNotResetOptions
 from .options.CounterScopeModelResetTypeIsDailyOptions import CounterScopeModelResetTypeIsDailyOptions
 from .options.CounterScopeModelResetTypeIsWeeklyOptions import CounterScopeModelResetTypeIsWeeklyOptions
 from .options.CounterScopeModelResetTypeIsMonthlyOptions import CounterScopeModelResetTypeIsMonthlyOptions
+from .options.CounterScopeModelResetTypeIsDaysOptions import CounterScopeModelResetTypeIsDaysOptions
 from .Namespace import Namespace
 from .options.NamespaceOptions import NamespaceOptions
 from .CounterModel import CounterModel
 from .options.CounterModelOptions import CounterModelOptions
 from .MissionGroupModel import MissionGroupModel
 from .options.MissionGroupModelOptions import MissionGroupModelOptions
-from .enum.MissionGroupModelResetType import MissionGroupModelResetType
-from .enum.MissionGroupModelResetDayOfWeek import MissionGroupModelResetDayOfWeek
+from .enums.MissionGroupModelResetType import MissionGroupModelResetType
+from .enums.MissionGroupModelResetDayOfWeek import MissionGroupModelResetDayOfWeek
 from .options.MissionGroupModelResetTypeIsNotResetOptions import MissionGroupModelResetTypeIsNotResetOptions
 from .options.MissionGroupModelResetTypeIsDailyOptions import MissionGroupModelResetTypeIsDailyOptions
 from .options.MissionGroupModelResetTypeIsWeeklyOptions import MissionGroupModelResetTypeIsWeeklyOptions
 from .options.MissionGroupModelResetTypeIsMonthlyOptions import MissionGroupModelResetTypeIsMonthlyOptions
+from .options.MissionGroupModelResetTypeIsDaysOptions import MissionGroupModelResetTypeIsDaysOptions
 from .MissionTaskModel import MissionTaskModel
 from .options.MissionTaskModelOptions import MissionTaskModelOptions
-from .enum.MissionTaskModelVerifyCompleteType import MissionTaskModelVerifyCompleteType
-from .enum.MissionTaskModelTargetResetType import MissionTaskModelTargetResetType
+from .enums.MissionTaskModelVerifyCompleteType import MissionTaskModelVerifyCompleteType
+from .enums.MissionTaskModelTargetResetType import MissionTaskModelTargetResetType
 from .options.MissionTaskModelVerifyCompleteTypeIsCounterOptions import MissionTaskModelVerifyCompleteTypeIsCounterOptions
 from .options.MissionTaskModelVerifyCompleteTypeIsVerifyActionsOptions import MissionTaskModelVerifyCompleteTypeIsVerifyActionsOptions
 from .ScopedValue import ScopedValue
 from .options.ScopedValueOptions import ScopedValueOptions
-from .enum.ScopedValueScopeType import ScopedValueScopeType
-from .enum.ScopedValueResetType import ScopedValueResetType
+from .enums.ScopedValueScopeType import ScopedValueScopeType
+from .enums.ScopedValueResetType import ScopedValueResetType
 from .options.ScopedValueScopeTypeIsResetTimingOptions import ScopedValueScopeTypeIsResetTimingOptions
 from .options.ScopedValueScopeTypeIsVerifyActionOptions import ScopedValueScopeTypeIsVerifyActionOptions
 from .TargetCounterModel import TargetCounterModel
 from .options.TargetCounterModelOptions import TargetCounterModelOptions
-from .enum.TargetCounterModelScopeType import TargetCounterModelScopeType
-from .enum.TargetCounterModelResetType import TargetCounterModelResetType
+from .enums.TargetCounterModelScopeType import TargetCounterModelScopeType
+from .enums.TargetCounterModelResetType import TargetCounterModelResetType
 from .options.TargetCounterModelScopeTypeIsResetTimingOptions import TargetCounterModelScopeTypeIsResetTimingOptions
 from .options.TargetCounterModelScopeTypeIsVerifyActionOptions import TargetCounterModelScopeTypeIsVerifyActionOptions
 from .VerifyActionResult import VerifyActionResult
