@@ -20,4 +20,12 @@ from .options.RandomStatusOptions import RandomStatusOptions
 from .RandomUsed import RandomUsed
 from .options.RandomUsedOptions import RandomUsedOptions
 from .Transaction import Transaction
-from .options.TransactionOptions import TransactionOptions
\ No newline at end of file
+from .options.TransactionOptions import TransactionOptions
+from .VerifyActionResult import VerifyActionResult
+from .options.VerifyActionResultOptions import VerifyActionResultOptions
+from .ConsumeActionResult import ConsumeActionResult
+from .options.ConsumeActionResultOptions import ConsumeActionResultOptions
+from .AcquireActionResult import AcquireActionResult
+from .options.AcquireActionResultOptions import AcquireActionResultOptions
+from .TransactionResult import TransactionResult
+from .options.TransactionResultOptions import TransactionResultOptions
\ No newline at end of file
